documentStore.SimpleDocumentStore

|  | ## Cheshire3 Object Model: Class SimpleDocumentStore

Module documentStore :: Class SimpleDocumentStore

## Class SimpleDocumentStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  ObjectStore --+
                                |
        baseObjects.DocumentStore --+
                                    |
                                   SimpleDocumentStore

Known Subclasses:
  BdbDocumentStore

Instance Methods

__init__(self, session, node, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
create_document(self, session, doc=None)
store_document(self, session, doc)
fetch_document(self, session, id)
delete_document(self, session, id)
Inherited from `baseObjects.DocumentStore`: `fetch_documentList` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

inPreParser |
outPreParser |
inWorkflow |
outWorkflow |
Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, node, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: configParser.C3Object.__init__ (inherited documentation)

### create_document(self, session, doc=None) | source code
Overrides: baseObjects.DocumentStore.create_document

### store_document(self, session, doc) | source code
Overrides: baseObjects.DocumentStore.store_document

### fetch_document(self, session, id) | source code
Overrides: baseObjects.DocumentStore.fetch_document

### delete_document(self, session, id) | source code
Overrides: baseObjects.DocumentStore.delete_document

Class Variable Details

    ### inPreParser Value:
        None

    ### outPreParser Value:
        None

    ### inWorkflow Value:
        None

    ### outWorkflow Value:
        None